// ======================================================================
//
// Light.h
// jeff grills
//
// copyright 1998 origin systems inc
//
// ======================================================================

#ifndef LIGHT_H
#define LIGHT_H

// ======================================================================
// includes

#include "ColorVector.h"
#include "Object.h"

// ======================================================================

class Light : public Object
{
protected:

	ColorVector color;

protected:

	void init(void);

private:

	// disable the copy constructor and the assignment operators
	Light(const Light &);
	Light &operator =(const Light &);

public:

	Light(ObjectId newObjectId, const ColorVector &newColor);
	virtual ~Light(void);

	// intensity inspection routines
	const ColorVector &getColor(void) const;
	void               setColor(const ColorVector &newColor);

	// render routines
	virtual void addToCamera(Camera &camera) = 0;
	virtual bool setup(const Xform &objectToWorld, const Appear *appear) const = 0;
	virtual void apply(const Xform &objectToWorld, const Vector &vertex, const Vector &normal, ColorVector *colorVector) const = 0;
};

// ======================================================================

inline const ColorVector &Light::getColor(void) const
{
	return color;
}

// ----------------------------------------------------------------------

inline void Light::setColor(const ColorVector &newColor)
{
	color = newColor;
}

// ======================================================================

#endif
